@@ -2,16 +2,22 @@
 library(optional)
 
 ## ------------------------------------------------------------------------
-a <- some(5)
+a <- option(5)
 class(a)
 
 ## ------------------------------------------------------------------------
 a == 5
 a
 
+## ------------------------------------------------------------------------
+a <- option(5)
+some(a)
+a <- none
+some(a)
+
 ## ------------------------------------------------------------------------
 c_opt <- make_opt(c)
-c_opt(some(2), none, some(5))
+c_opt(option(2), none, option(5))
 c_opt()
 
 ## ------------------------------------------------------------------------
@@ -19,7 +25,7 @@ library(magrittr)
 
 a <- 5
 match_with(a,
-  . %>% some(.),          paste,
+  . %>% option(.),          paste,
   none,                   function() "Error!"
 )
 
